function C = designpi(G,omega,zeta)
% DESIGNPI  Designs a PI controller for the first-order continuous-time
%           LTI system G using pole placement.
%
%           C = DESIGNPI(G,omega,zeta)
%
%           The characteristic polynomial of the closed loop is
%           specified as s^2+2*zeta*omega*s+omega^2

if ~isa(G,'lti')
  error('G must be an LTI system')
end
G = tf(G);

if ~issiso(G) || ~isct(G) || size(G,'order') ~= 1 || ~isproper(G)
  error('G must be a continuous-time proper first-order SISO system')
end

[B,A] = tfdata(G,'v');
Acl = [1 2*zeta*omega omega^2];
[R,S] = rstc(1,B,A,1,Acl,1,[1 0]);
C = tf(S,R);
